@@ -285,7 +285,7 @@ class TestGetAuth(MockHttpTest):
                           'asdf', 'asdf',
                           auth_version='1.0')
 
-    def test_auth_v2(self):
+    def test_auth_v2_with_tenant_name(self):
         os_options = {'tenant_name': 'asdf'}
         c.get_keystoneclient_2_0 = fake_get_keystoneclient_2_0(os_options)
         url, token = c.get_auth('http://www.test.com', 'asdf', 'asdf',
@@ -294,13 +294,31 @@ class TestGetAuth(MockHttpTest):
         self.assertTrue(url.startswith("http"))
         self.assertTrue(token)
 
-    def test_auth_v2_no_tenant_name(self):
+    def test_auth_v2_with_tenant_id(self):
+        os_options = {'tenant_id': 'asdf'}
+        c.get_keystoneclient_2_0 = fake_get_keystoneclient_2_0(os_options)
+        url, token = c.get_auth('http://www.test.com', 'asdf', 'asdf',
+                                os_options=os_options,
+                                auth_version="2.0")
+        self.assertTrue(url.startswith("http"))
+        self.assertTrue(token)
+
+    def test_auth_v2_no_tenant_name_or_tenant_id(self):
         c.get_keystoneclient_2_0 = fake_get_keystoneclient_2_0({})
         self.assertRaises(c.ClientException, c.get_auth,
                           'http://www.tests.com', 'asdf', 'asdf',
                           os_options={},
                           auth_version='2.0')
 
+    def test_auth_v2_with_tenant_name_none_and_tenant_id_none(self):
+        os_options = {'tenant_name': None,
+                      'tenant_id': None}
+        c.get_keystoneclient_2_0 = fake_get_keystoneclient_2_0(os_options)
+        self.assertRaises(c.ClientException, c.get_auth,
+                          'http://www.tests.com', 'asdf', 'asdf',
+                          os_options=os_options,
+                          auth_version='2.0')
+
     def test_auth_v2_with_tenant_user_in_user(self):
         tenant_option = {'tenant_name': 'foo'}
         c.get_keystoneclient_2_0 = fake_get_keystoneclient_2_0(tenant_option)
@@ -727,8 +745,8 @@ class TestPutObject(MockHttpTest):
         c.put_object(url='http://www.test.com', http_conn=conn,
                      etag='1234-5678', content_type='text/plain')
         request_header = resp.requests_params['headers']
-        self.assertTrue(request_header['etag'], '1234-5678')
-        self.assertTrue(request_header['content-type'], 'text/plain')
+        self.assertEqual(request_header['etag'], b'1234-5678')
+        self.assertEqual(request_header['content-type'], b'text/plain')
 
     def test_no_content_type(self):
         conn = c.http_connection(u'http://www.test.com/')
@@ -824,8 +842,8 @@ class TestHTTPConnection(MockHttpTest):
     def test_ok_proxy(self):
         conn = c.http_connection(u'http://www.test.com/',
                                  proxy='http://localhost:8080')
-        self.assertEquals(conn[1].requests_args['proxies']['http'],
-                          'http://localhost:8080')
+        self.assertEqual(conn[1].requests_args['proxies']['http'],
+                         'http://localhost:8080')
 
     def test_bad_proxy(self):
         try:
@@ -836,11 +854,11 @@ class TestHTTPConnection(MockHttpTest):
     def test_cacert(self):
         conn = c.http_connection(u'http://www.test.com/',
                                  cacert='/dev/urandom')
-        self.assertEquals(conn[1].requests_args['verify'], '/dev/urandom')
+        self.assertEqual(conn[1].requests_args['verify'], '/dev/urandom')
 
     def test_insecure(self):
         conn = c.http_connection(u'http://www.test.com/', insecure=True)
-        self.assertEquals(conn[1].requests_args['verify'], False)
+        self.assertEqual(conn[1].requests_args['verify'], False)
 
 
 class TestConnection(MockHttpTest):
@@ -1166,7 +1184,3 @@ class TestCloseConnection(MockHttpTest):
         conn.close()
         self.assertEqual(http_conn_obj.isclosed(), True)
         self.assertEqual(conn.http_conn, None)
-
-
-if __name__ == '__main__':
-    testtools.main()
